# Installation

The package is easy to install and keep up to date.

## Pip 📦

Install `aifn` using [`pip`](https://pip.pypa.io/en/stable/getting-started/):
```bash
pip install aifn
```
*We always recommend installing the package within a python virtual environment or conda environment.*

If you already have the package and simply want to upgrade:
```bash
pip install --upgrade aifn
```

## Source 📖

You can also install from [`source`](https://github.com/WecoAI/aifn-python):
```bash
git clone https://github.com/WecoAI/aifn-python
cd aifn-python
python install -e .
```

To upgrade the package to the latest version from [`source`](https://github.com/WecoAI/aifn-python), you can run the following commands:
```bash
cd aifn-python
git pull origin main
python install -e .
```

## Jump In 🏊‍♂️

If you need help getting started, you can check out any of the following resources we provide:

- [Introduction](introduction.md)
- [Cookbook](../cookbook/cookbook.md)
- [API Reference](../api/api.md)

Happy building!
